@@ -8,12 +8,11 @@ is_design <- function(object) {
 
 #' Sanitize model outputs
 #' @param os Given outputs. Character vector
-#' @param m A model name
+#' @param moutputs Model outputs. Character vector
 #' @return A character vector
 #' @note If os is not NULL, cuts extraneous outputs.
 #' @noRd
-.sanitize_outputs <- function(os, m) {
-  moutputs <- model_outputs(m)
+.sanitize_outputs <- function(os, moutputs) {
   if (is.null(os)) {
     return(moutputs)
   }
@@ -30,17 +29,44 @@ is_design <- function(object) {
 }
 
 .assert_model <- function(model) {
+  # check if the model class exists
+  tryCatch(
+    {
+      obj <- methods::new(model)
+    },
+    error = function(e) {
+      stop(sprintf("Model class '%s' does not exist in the namespace.
+      Check `supported_models()`", model), call. = FALSE)
+    }
+  )
+  # check that the model inherits from CalmrModel
   stopifnot(
-    "Model must be one returned by `supported_models()`" =
-      (model %in% supported_models())
+    "User models must inherit from CalmrModel" =
+      methods::is(obj, "CalmrModel")
   )
   model
 }
 
 .assert_timed_model <- function(model) {
+  tryCatch(
+    {
+      obj <- methods::new(model)
+    },
+    error = function(e) {
+      stop(paste(
+        sprintf(
+          "Model class '%s' does not exist in the namespace.",
+          model
+        ), "Check `supported_timed_models()`"
+      ), call. = FALSE)
+    }
+  )
+  if (!obj@.is_timed) {
+
+  }
   stopifnot(
-    "Model must be one returned by `supported_timed_models()`" =
-      (model %in% supported_timed_models())
+    "Class definition must have .is_timed flag set to TRUE" =
+      obj@.is_timed
   )
   model
 }
@@ -149,12 +175,17 @@ is_design <- function(object) {
 }
 
 .assert_valid_palette <- function(palette) {
-  if (is.null(palette)) {
-    return("viridis")
-  }
   stopifnot(
     "Palette must be one returned by `set_calmr_palette()`" =
       palette %in% set_calmr_palette()
   )
   palette
 }
+
+.assert_has_parameters <- function(object) {
+  stopifnot(
+    "Model parameters are not set.
+  Use `parameters<-` to set them." =
+      (!is.null(object@parameters) && length(object@parameters) > 0)
+  )
+}
