@@ -13,23 +13,17 @@ get_design <- function(design_name = NULL) {
     "blocking" = data.frame(
       Group = c("Blocking", "Control"),
       P1 = c("10N>(US)", ""),
-      R1 = FALSE,
-      P2 = c("10NL>(US)/10#L", "10NL>(US)/10#L"),
-      R2 = FALSE
+      P2 = c("10NL>(US)/10#L", "10NL>(US)/10#L")
     ),
     "relative_validity" = data.frame(
       Group = c("True", "Pseudo"),
-      P1 = c("10AB(US)/10AC", "5AB(US)/5AB/5AC(US)/5AC"),
-      R1 = c(TRUE, TRUE),
-      P2 = c("1#A", "1#A"),
-      R2 = c(TRUE, TRUE)
+      P1 = c("!10AB(US)/10AC", "!5AB(US)/5AB/5AC(US)/5AC"),
+      P2 = c("1#A", "1#A")
     ),
     "controlled_blocking" = data.frame(
       Group = c("Blocking", "Control"),
       P1 = c("10N>(US)", "10C>(US)"),
-      R1 = FALSE,
-      P2 = c("10NL>(US)/10#L", "10NL>(US)/10#L"),
-      R2 = FALSE
+      P2 = c("10NL>(US)/10#L", "10NL>(US)/10#L")
     )
   )
   if (is.null(design_name)) {
