@@ -52,47 +52,43 @@ run_experiment <- function(
     "parameters", "timings",
     "experience", "mapping"
   ))]
-  # sanitize outputs
-  outputs <- .sanitize_outputs(outputs, experiment@model)
+  # sanitize outputs using the first model
+  outputs <- .sanitize_outputs(outputs, experiment@models[[1]]@outputs)
 
   # check if experiment needs (can) to be run
   .assert_experiment(experiment)
 
+  # check model/experiment parameters
+  experiment <- .assert_model_exp_parameters(experiment)
+
   # now run the experiment
   exp_length <- length(experiment)
   pb <- progressr::progressor(exp_length)
   .parallel_standby(pb) # print parallel backend message
   # get results
-  all_results <- future.apply::future_sapply(
+  experiment@models <- future.apply::future_sapply(
     seq_len(exp_length), function(i) {
       if (!is.null(nargs$.callback_fn)) nargs$.callback_fn() # nocov
       # bundle arguments
       args <- c(list(
+        object = experiment@models[[i]],
         experience = experiment@experiences[[i]],
         mapping = experiment@design@mapping,
-        parameters = experiment@parameters[[experiment@.group[i]]],
         timings = experiment@timings
       ), nargs)
-      raw <- do.call(get_model(experiment@.model[i]), args)
-      parsed <- NULL
+
+      mod <- do.call(calmr::run, args)
+
+      # parse results
       if (parse) {
-        parsed <- .parse_model(
-          raw = raw,
-          experience = args$experience,
-          model = experiment@.model[i],
-          outputs = outputs
-        )
+        mod <- parse(mod, outputs)
       }
       pb(message = "Running experiment")
-      list(raw = raw, parsed = parsed)
+      mod
     },
     simplify = FALSE,
     future.seed = TRUE
   )
-  experiment@results@raw_results <- lapply(all_results, "[[", "raw")
-  if (parse) {
-    experiment@results@parsed_results <- lapply(all_results, "[[", "parsed")
-  }
   # aggregate
   if (aggregate) {
     experiment <- aggregate(experiment, outputs = outputs)
@@ -100,3 +96,22 @@ run_experiment <- function(
 
   return(experiment)
 }
+
+.assert_model_exp_parameters <- function(experiment) {
+  # here we check whether the model parameters match
+  # the ones set in the experiment
+
+  # if the user modifies the parameters after the experiment is created,
+  # then the parameters will not match
+
+  # the parameters are named after the group names
+  for (i in seq_len(length(experiment))) {
+    epars <- experiment@parameters[[experiment@.groups[i]]]
+    mpars <- experiment@models[[i]]@parameters
+    matches <- mapply(function(a, b) all(a %in% b), epars, mpars)
+    if (!all(matches)) {
+      experiment@models[[i]]@parameters <- epars
+    }
+  }
+  experiment
+}
